Nexml module — ETE Toolkit - analysis and visualization of trees

New in version 2.1.

# Nexml module

## Nexml classes linked to ETE

class `Nexml`(*args, **kargs)

  Creates a new nexml project.

  `build_from_file`(fname, index_otus=True)

    Populate Nexml project with data in a nexml file.

class `NexmlTree`(newick=None, alignment=None, alg_format='fasta', sp_naming_function=<function _parse_species>, format=0)

  Special PhyloTree object with nexml support

## Generic Nexml classes

class `AAChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  A concrete implementation of the AbstractChar element.

  `superclass`

    alias of `AbstractChar`

class `AAFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The AAFormat class is the container of amino acid column definitions.

  `superclass`

    alias of `AbstractFormat`

class `AAMapping`(state=None, valueOf_=None)

  An IUPAC ambiguity mapping.

  `superclass`

    alias of `AbstractMapping`

class `AAMatrixObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  This is a row in a matrix of amino acid data containing granular observations.

  `superclass`

    alias of `AbstractObsRow`

class `AAMatrixSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  This is a row in a matrix of amino acid data containing raw sequence data.

  `superclass`

    alias of `AbstractSeqRow`

class `AAObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  This is a single cell in a matrix containing an amino acid observation.

  `superclass`

    alias of `AbstractObs`

class `AAObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with single character observations.

  `superclass`

    alias of `AbstractObsMatrix`

class `AAPolymorphicStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, uncertain_state_set=None, valueOf_=None)

  The AAPolymorphicStateSet defines a polymorphic ambiguity mapping.

  `superclass`

    alias of `AbstractPolymorphicStateSet`

class `AASeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with amino acid data as sequence strings.

  `superclass`

    alias of `AbstractSeqMatrix`

class `AAState`(about=None, meta=None, label=None, id=None, symbol=None, valueOf_=None)

  This is a concrete implementation of the state element, which requires a symbol element, in this case restricted to AAToken, i.e. a single IUPAC amino acid symbol, and optional mapping elements to refer to other states.

  `superclass`

    alias of `AbstractState`

class `AAStates`(about=None, meta=None, label=None, id=None, state=None, polymorphic_state_set=None, uncertain_state_set=None, set=None, valueOf_=None)

  A container for a set of states.

  `superclass`

    alias of `AbstractStates`

class `AAUncertainStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, valueOf_=None)

  The AAUncertainStateSet defines an uncertain ambiguity mapping.

  `superclass`

    alias of `AbstractUncertainStateSet`

class `AbstractBlock`(about=None, meta=None, label=None, id=None, otus=None, format=None, valueOf_=None)

  The AbstractBlock is the superclass for blocks that contain an element structure of type AbstractFormat.

  `superclass`

    alias of `TaxaLinked`

class `AbstractCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  The AbstractSeqBlock type is the superclass for character blocks that consist of granular character state observations.

  `superclass`

    alias of `AbstractBlock`

class `AbstractChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  The AbstractChar type is the superclass for a column definition, which may have a “states” attribute that refers to an AbstractStates element, a codon attribute of type CodonPosition and an id attribute that may be an actual id (e.g. for categorical matrices where observations explicitly refer to a column definition) or an integer for sequence matrices.

  `superclass`

    alias of `IDTagged`

class `AbstractEdge`(about=None, meta=None, label=None, id=None, source=None, length=None, target=None, valueOf_=None)

  The AbstractEdge superclass is what concrete edges inherit from by restriction. It represents an edge element much like that of GraphML, i.e. an element that connects node elements.

  `superclass`

    alias of `IDTagged`

class `AbstractFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The AbstractFormat type is the superclass for the element that defines the allowed characters and states in a matrix, and their ambiguity mapping. It may enclose AbstractStates elements that define states and their mappings, and AbstractChar elements that specify which AbstractStates apply to which matrix columns.

  `superclass`

    alias of `Annotated`

class `AbstractMapping`(state=None, valueOf_=None)

  The AbstractMapping type is the superclass for an ambiguity mapping. In an instance document, a subclass of this type will look like <member state=”st1”/>, i.e. an element called “member” with an attribute called “state” whose value is an id reference that refers to an element that subclasses AbstractState. The purpose of AbstractMapping is to specify which other states may be implied, e.g. a nucleotide symbol “N” would have mappings to “A”, “C”, “G” and “T”.

  `superclass`

    alias of `Base`

class `AbstractNetwork`(about=None, meta=None, label=None, id=None, node=None, edge=None, set=None, valueOf_=None)

  The AbstractNetwork superclass is what a concrete network inherits from.

  `superclass`

    alias of `IDTagged`

class `AbstractNode`(about=None, meta=None, label=None, id=None, otu=None, root=False, valueOf_=None)

  The AbstractNode superclass is what concrete nodes inherit from by restriction. It represents a node element much like that of GraphML, i.e. an element that is connected into a tree by edge elements.

  `superclass`

    alias of `OptionalTaxonLinked`

class `AbstractObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  The AbstractObs type is the superclass for single observations, i.e. cells in a matrix. A concrete instance of AbstractObs has a “char” attribute that refers to an explicitly defined character (e.g. in categorical matrices), and a “state” attribute that either holds a reference to an explicitly defined state, or a raw state value (a continuous value).

  `superclass`

    alias of `Labelled`

class `AbstractObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  The AbstractObsMatrix super class is the abstract type for a <matrix> element that contains rows which hold granular state observations.

  `superclass`

    alias of `Annotated`

class `AbstractObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  The AbstractObsRow represents a single row in a matrix. The row must refer to a previously declared otu element by its id attribute (and must have an id itself, may have a label, and may have meta attachments). The row contains multiple cell elements.

  `superclass`

    alias of `TaxonLinked`

class `AbstractPolymorphicStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, uncertain_state_set=None, valueOf_=None)

  The AbstractPolymorphicStateSet type is the super-class for a polymorphic state set definition. The element has a required AbstractSymbol attribute that in restricted concrete subclasses must be of a sensible type such as a single IUPAC character. It may enclose zero or more AbstractMapping elements to resolve ambiguities.

  `superclass`

    alias of `AbstractUncertainStateSet`

class `AbstractRootEdge`(about=None, meta=None, label=None, id=None, length=None, target=None, valueOf_=None)

  The AbstractRootEdge complex type is a superclass for the edge that leads into a root, i.e. an edge with only a target attribute, but no source attribute. This type of edge is used for coalescent trees, where the initial lineage has a certain length before things start splitting up.

  `superclass`

    alias of `IDTagged`

class `AbstractSeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  The AbstractSeqMatrix super class is the abstract type for a <matrix> element that contains rows which hold raw character sequences.

  `superclass`

    alias of `Annotated`

class `AbstractSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  The AbstractSeqRow represents a single row in a matrix. The row must refer to a previously declared otu element by its id attribute (and must have an id itself, may have a label, and may have meta attachments). The row contains a single seq element with raw character data.

  `superclass`

    alias of `TaxonLinked`

class `AbstractSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  The AbstractSeqBlock type is the superclass for character blocks that consist of raw character sequences.

  `superclass`

    alias of `AbstractBlock`

class `AbstractState`(about=None, meta=None, label=None, id=None, symbol=None, valueOf_=None)

  The AbstractState type is the super-class for a state definition. The element has a required symbol attribute that in restricted concrete subclasses must be of a sensible type such as a single IUPAC character. It may enclose zero or more AbstractMapping elements to resolve ambiguities.

  `superclass`

    alias of `IDTagged`

class `AbstractStates`(about=None, meta=None, label=None, id=None, state=None, polymorphic_state_set=None, uncertain_state_set=None, set=None, valueOf_=None)

  A container for a set of AbstractState elements.

  `superclass`

    alias of `IDTagged`

class `AbstractTree`(about=None, meta=None, label=None, id=None, node=None, rootedge=None, edge=None, set=None, valueOf_=None)

  The AbstractTree superclass is what a concrete tree inherits from.

  `superclass`

    alias of `IDTagged`

class `AbstractTrees`(about=None, meta=None, label=None, id=None, network=None, tree=None, set=None, valueOf_=None)

  The AbstractTrees superclass is what concrete trees inherit from.

  `superclass`

    alias of `IDTagged`

class `AbstractUncertainStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, valueOf_=None)

  The AbstractUncertainStateSet type is the super-class for an uncertain state set definition. The element has a required AbstractSymbol attribute that in restricted concrete subclasses must be of a sensible type such as a single IUPAC character. It may enclose zero or more AbstractMapping elements to resolve ambiguities.

  `superclass`

    alias of `AbstractState`

class `Annotated`(about=None, meta=None, valueOf_=None)

  The Annotated complexType is a super class for objects that optionally have metadata annotations of type Meta.

  `superclass`

    alias of `Base`

class `Base`(valueOf_=None)

  The base type for all complexType definitions in the nexml schema. This type allows a number of special attributes: xml:lang - for languages codes xml:base - see http://www.w3.org/TR/xmlbase/ xml:id - see http://www.w3.org/TR/xml-id/ xml:space - for whitespace handling xlink:href - for links Also see http://www.w3.org/2001/xml.xsd for more information on the xml and xlink attributes.

class `ContinuousCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A continuous characters block consisting of granular cells preceded by metadata.

  `superclass`

    alias of `AbstractCells`

class `ContinuousChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  A concrete implementation of the char element, which requires only an id attribute.

  `superclass`

    alias of `AbstractChar`

class `ContinuousFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The ContinuousFormat class is the container of continuous column definitions.

  `superclass`

    alias of `AbstractFormat`

class `ContinuousMatrixObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  This is a row in a matrix of continuous data as granular obervations.

  `superclass`

    alias of `AbstractObsRow`

class `ContinuousMatrixSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  This is a row in a matrix of continuous data as character sequences.

  `superclass`

    alias of `AbstractSeqRow`

class `ContinuousObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  This is a single cell in a matrix containing a continuous observation.

  `superclass`

    alias of `AbstractObs`

class `ContinuousObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with single character observations.

  `superclass`

    alias of `AbstractObsMatrix`

class `ContinuousSeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with seq strings of type continuous.

  `superclass`

    alias of `AbstractSeqMatrix`

class `ContinuousSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A continuous characters block consisting of float sequences preceded by metadata.

  `superclass`

    alias of `AbstractSeqs`

class `DNAChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  A concrete implementation of the AbstractChar element.

  `superclass`

    alias of `AbstractChar`

class `DNAFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The DNAFormat class is the container of DNA column definitions.

  `superclass`

    alias of `AbstractFormat`

class `DNAMapping`(state=None, valueOf_=None)

  An IUPAC ambiguity mapping.

  `superclass`

    alias of `AbstractMapping`

class `DNAMatrixObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  This is a row in a matrix of DNA data containing granular observations.

  `superclass`

    alias of `AbstractObsRow`

class `DNAMatrixSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  This is a row in a matrix of DNA data containing raw sequence data.

  `superclass`

    alias of `AbstractSeqRow`

class `DNAObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  This is a single cell in a matrix containing a nucleotide observation.

  `superclass`

    alias of `AbstractObs`

class `DNAObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with single character observations.

  `superclass`

    alias of `AbstractObsMatrix`

class `DNAPolymorphicStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, uncertain_state_set=None, valueOf_=None)

  The DNAPolymorphicStateSet type defines an IUPAC ambiguity mapping. It may enclose zero or more AbstractMapping elements to resolve ambiguities.

  `superclass`

    alias of `AbstractPolymorphicStateSet`

class `DNASeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with seq strings of type DNA.

  `superclass`

    alias of `AbstractSeqMatrix`

class `DNAState`(about=None, meta=None, label=None, id=None, symbol=None, valueOf_=None)

  This is a concrete implementation of the state element, which requires a symbol element, in this case restricted to DNAToken, i.e. a single IUPAC nucleotide symbol, and optional mapping elements to refer to other states.

  `superclass`

    alias of `AbstractState`

class `DNAStates`(about=None, meta=None, label=None, id=None, state=None, polymorphic_state_set=None, uncertain_state_set=None, set=None, valueOf_=None)

  A container for a set of states.

  `superclass`

    alias of `AbstractStates`

class `DNAUncertainStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, valueOf_=None)

  The DNAUncertainStateSet type defines an IUPAC ambiguity mapping. It may enclose zero or more AbstractMapping elements to resolve ambiguities.

  `superclass`

    alias of `AbstractUncertainStateSet`

class `DnaCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A DNA characters block consisting of granular cells preceded by metadata.

  `superclass`

    alias of `AbstractCells`

class `DnaSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A DNA characters block consisting of sequences preceded by metadata.

  `superclass`

    alias of `AbstractSeqs`

class `FloatNetwork`(about=None, meta=None, label=None, id=None, node=None, edge=None, set=None, valueOf_=None)

  A concrete network implementation, with floating point edge lengths.

  `superclass`

    alias of `AbstractNetwork`

class `FloatTree`(about=None, meta=None, label=None, id=None, node=None, rootedge=None, edge=None, set=None, valueOf_=None)

  A concrete tree implementation, with floating point edge lengths.

  `subclass`

    alias of `NexmlTree`

  `superclass`

    alias of `AbstractTree`

class `IDTagged`(about=None, meta=None, label=None, id=None, valueOf_=None)

  The IDTagged complexType is a super class for objects that require unique id attributes of type xs:ID. The id must be unique within the XML document.

  `superclass`

    alias of `Labelled`

class `IntNetwork`(about=None, meta=None, label=None, id=None, node=None, edge=None, set=None, valueOf_=None)

  A concrete network implementation, with integer edge lengths.

  `superclass`

    alias of `AbstractNetwork`

class `IntTree`(about=None, meta=None, label=None, id=None, node=None, rootedge=None, edge=None, set=None, valueOf_=None)

  A concrete tree implementation, with integer edge lengths.

  `subclass`

    alias of `NexmlTree`

  `superclass`

    alias of `AbstractTree`

class `Labelled`(about=None, meta=None, label=None, valueOf_=None)

  The Labelled complexType is a super class for objects that optionally have label attributes to use as a (non-unique) name of type xs:string.

  `superclass`

    alias of `Annotated`

class `LiteralMeta`(datatype=None, content=None, property=None, valueOf_=None)

  Metadata annotations in which the object is a literal value. If the @content attribute is used, then the element should contain no children.

class `NetworkFloatEdge`(about=None, meta=None, label=None, id=None, source=None, length=None, target=None, valueOf_=None)

  A concrete network edge implementation, with float edge.

  `superclass`

    alias of `AbstractEdge`

class `NetworkIntEdge`(about=None, meta=None, label=None, id=None, source=None, length=None, target=None, valueOf_=None)

  A concrete network edge implementation, with int edge.

  `superclass`

    alias of `AbstractEdge`

class `NetworkNode`(about=None, meta=None, label=None, id=None, otu=None, root=False, valueOf_=None)

  A concrete network node implementation.

  `superclass`

    alias of `AbstractNode`

class `Nexml`(*args, **kargs)

  Creates a new nexml project.

  `build_from_file`(fname, index_otus=True)

    Populate Nexml project with data in a nexml file.

class `OptionalTaxonLinked`(about=None, meta=None, label=None, id=None, otu=None, valueOf_=None)

  The OptionalOTULinked complexType is a super class for objects that that optionally have an otu id reference.

  `superclass`

    alias of `IDTagged`

class `ProteinCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  An amino acid characters block consisting of granular cells preceded by metadata.

  `superclass`

    alias of `AbstractCells`

class `ProteinSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  An amino acid characters block consisting of sequences preceded by metadata.

  `superclass`

    alias of `AbstractSeqs`

class `RNAChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  A concrete implementation of the AbstractChar element, i.e. a single column in an alignment.

  `superclass`

    alias of `AbstractChar`

class `RNAFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The RNAFormat class is the container of RNA column definitions.

  `superclass`

    alias of `AbstractFormat`

class `RNAMapping`(state=None, valueOf_=None)

  An IUPAC RNA ambiguity mapping.

  `superclass`

    alias of `AbstractMapping`

class `RNAMatrixObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  This is a row in a matrix of RNA data containing granular observations.

  `superclass`

    alias of `AbstractObsRow`

class `RNAMatrixSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  This is a row in a matrix of RNA data containing raw sequence data.

  `superclass`

    alias of `AbstractSeqRow`

class `RNAObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  This is a single cell in a matrix containing an RNA nucleotide observation.

  `superclass`

    alias of `AbstractObs`

class `RNAObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with single character observations.

  `superclass`

    alias of `AbstractObsMatrix`

class `RNAPolymorphicStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, uncertain_state_set=None, valueOf_=None)

  The RNAPolymorphicStateSet describes a single polymorphic IUPAC ambiguity mapping.

  `superclass`

    alias of `AbstractPolymorphicStateSet`

class `RNASeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with seq strings of type RNA.

  `superclass`

    alias of `AbstractSeqMatrix`

class `RNAState`(about=None, meta=None, label=None, id=None, symbol=None, valueOf_=None)

  This is a concrete implementation of the state element, which requires a symbol attribute, in this case restricted to RNAToken, i.e. a single IUPAC nucleotide symbol, and optional mapping elements to refer to other states.

  `superclass`

    alias of `AbstractState`

class `RNAStates`(about=None, meta=None, label=None, id=None, state=None, polymorphic_state_set=None, uncertain_state_set=None, set=None, valueOf_=None)

  A container for a set of states.

  `superclass`

    alias of `AbstractStates`

class `RNAUncertainStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, valueOf_=None)

  The RNAUncertainStateSet describes a single uncertain IUPAC ambiguity mapping.

  `superclass`

    alias of `AbstractUncertainStateSet`

class `ResourceMeta`(href=None, rel=None, meta=None, valueOf_=None)

  Metadata annotations in which the object is a resource. If this element contains meta elements as children, then the object of this annotation is a “blank node”.

class `RestrictionCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A standard characters block consisting of granular cells preceded by metadata.

  `superclass`

    alias of `AbstractCells`

class `RestrictionChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  A concrete implementation of the char element, which requires a unique identifier and a state set reference.

  `superclass`

    alias of `AbstractChar`

class `RestrictionFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The RestrictionFormat class is the container of restriction column definitions.

  `superclass`

    alias of `AbstractFormat`

class `RestrictionMatrixObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  This is a row in a matrix of restriction site data as granular obervations.

  `superclass`

    alias of `AbstractObsRow`

class `RestrictionMatrixSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  This is a row in a matrix of restriction site data as character sequences.

  `superclass`

    alias of `AbstractSeqRow`

class `RestrictionObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  This is a single cell in a matrix containing a restriction site observation.

  `superclass`

    alias of `AbstractObs`

class `RestrictionObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with single character observations.

  `superclass`

    alias of `AbstractObsMatrix`

class `RestrictionSeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with seq strings of type restriction.

  `superclass`

    alias of `AbstractSeqMatrix`

class `RestrictionSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A restriction site characters block consisting of sequences preceded by metadata.

  `superclass`

    alias of `AbstractSeqs`

class `RestrictionState`(about=None, meta=None, label=None, id=None, symbol=None, valueOf_=None)

  This is a concrete implementation of the state element, which requires a symbol element, in this case restricted to 0/1.

  `superclass`

    alias of `AbstractState`

class `RestrictionStates`(about=None, meta=None, label=None, id=None, state=None, polymorphic_state_set=None, uncertain_state_set=None, set=None, valueOf_=None)

  A container for a set of states.

  `superclass`

    alias of `AbstractStates`

class `RnaCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A RNA characters block consisting of granular cells preceded by metadata.

  `superclass`

    alias of `AbstractCells`

class `RnaSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A RNA characters block consisting of sequences preceded by metadata.

  `superclass`

    alias of `AbstractSeqs`

class `StandardCells`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A standard characters block consisting of granular cells preceded by metadata.

  `superclass`

    alias of `AbstractCells`

class `StandardChar`(about=None, meta=None, label=None, id=None, tokens=None, states=None, codon=None, valueOf_=None)

  A concrete implementation of the char element, which requires a states attribute to refer to a set of defined states

  `superclass`

    alias of `AbstractChar`

class `StandardFormat`(about=None, meta=None, states=None, char=None, set=None, valueOf_=None)

  The StandardFormat class is the container of standard column definitions.

  `superclass`

    alias of `AbstractFormat`

class `StandardMapping`(state=None, valueOf_=None)

  A standard character ambiguity mapping.

  `superclass`

    alias of `AbstractMapping`

class `StandardMatrixObsRow`(about=None, meta=None, label=None, id=None, otu=None, cell=None, set=None, valueOf_=None)

  This is a row in a matrix of standard data as granular obervations.

  `superclass`

    alias of `AbstractObsRow`

class `StandardMatrixSeqRow`(about=None, meta=None, label=None, id=None, otu=None, seq=None, valueOf_=None)

  This is a row in a matrix of standard data as character sequences.

  `superclass`

    alias of `AbstractSeqRow`

class `StandardObs`(about=None, meta=None, label=None, char=None, state=None, valueOf_=None)

  This is a single cell in a matrix containing a standard observation.

  `superclass`

    alias of `AbstractObs`

class `StandardObsMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with single character observations.

  `superclass`

    alias of `AbstractObsMatrix`

class `StandardPolymorphicStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, uncertain_state_set=None, valueOf_=None)

  The StandardPolymorphicStateSet type is a single polymorphic ambiguity mapping.

  `superclass`

    alias of `AbstractPolymorphicStateSet`

class `StandardSeqMatrix`(about=None, meta=None, row=None, set=None, valueOf_=None)

  A matrix of rows with seq strings of type standard.

  `superclass`

    alias of `AbstractSeqMatrix`

class `StandardSeqs`(about=None, meta=None, label=None, id=None, otus=None, format=None, matrix=None, valueOf_=None)

  A standard characters block consisting of sequences preceded by metadata.

  `superclass`

    alias of `AbstractSeqs`

class `StandardState`(about=None, meta=None, label=None, id=None, symbol=None, valueOf_=None)

  This is a concrete implementation of the state element, which requires a symbol element, in this case restricted to integers, and optional mapping elements to refer to other states.

  `superclass`

    alias of `AbstractState`

class `StandardStates`(about=None, meta=None, label=None, id=None, state=None, polymorphic_state_set=None, uncertain_state_set=None, set=None, valueOf_=None)

  A container for a set of states.

  `superclass`

    alias of `AbstractStates`

class `StandardUncertainStateSet`(about=None, meta=None, label=None, id=None, symbol=None, member=None, valueOf_=None)

  The StandardUncertainStateSet type is a single uncertain ambiguity mapping.

  `superclass`

    alias of `AbstractUncertainStateSet`

class `TaxaLinked`(about=None, meta=None, label=None, id=None, otus=None, valueOf_=None)

  The TaxaLinked complexType is a super class for objects that that require an otus id reference.

  `superclass`

    alias of `IDTagged`

class `TaxonLinked`(about=None, meta=None, label=None, id=None, otu=None, valueOf_=None)

  The TaxonLinked complexType is a super class for objects that require a taxon id reference.

  `superclass`

    alias of `IDTagged`

class `TreeFloatEdge`(about=None, meta=None, label=None, id=None, source=None, length=None, target=None, valueOf_=None)

  A concrete edge implementation, with float length.

  `superclass`

    alias of `AbstractEdge`

class `TreeFloatRootEdge`(about=None, meta=None, label=None, id=None, length=None, target=None, valueOf_=None)

  A concrete root edge implementation, with float length.

  `superclass`

    alias of `AbstractRootEdge`

class `TreeIntEdge`(about=None, meta=None, label=None, id=None, source=None, length=None, target=None, valueOf_=None)

  A concrete edge implementation, with int length.

  `superclass`

    alias of `AbstractEdge`

class `TreeIntRootEdge`(about=None, meta=None, label=None, id=None, length=None, target=None, valueOf_=None)

  A concrete root edge implementation, with int length.

  `superclass`

    alias of `AbstractRootEdge`

class `TreeNode`(about=None, meta=None, label=None, id=None, otu=None, root=False, valueOf_=None)

  A concrete node implementation.

  `superclass`

    alias of `AbstractNode`

class `Trees`(about=None, meta=None, label=None, id=None, otus=None, network=None, tree=None, set=None, valueOf_=None)

  A concrete container for tree objects.

  `superclass`

    alias of `TaxaLinked`

class `attrExtensions`(valueOf_=None)

  This element is for use in WSDL 1.1 only. It does not apply to WSDL 2.0 documents. Use in WSDL 2.0 documents is invalid.

class `Nexml`(*args, **kargs)

  Creates a new nexml project.

  `build_from_file`(fname, index_otus=True)

    Populate Nexml project with data in a nexml file.

class `NexmlTree`(newick=None, alignment=None, alg_format='fasta', sp_naming_function=<function _parse_species>, format=0)

  Special PhyloTree object with nexml support